# Change Log

## 0.0.0.1
- First Release

## 0.0.0.2
- Real camera exception checker added

## 0.0.0.5
- Hope this works

## 0.0.0.6
- Servo motors should work now

## 0.0.0.7
- Thread joins added

## 0.0.0.8
- Thread joins fixed :)